Module and Class Hierarchies

[frames | no frames]

## Module Hierarchy

- `pyparsing`: pyparsing module - Classes and methods to define and execute parsing grammars

## Class Hierarchy

- `__builtin__.object`: The most base type
  - `parserFwk.pyparsing.OnlyOnce`: Wrapper for parse actions, to ensure they are only called once.
  - `parserFwk.pyparsing.ParserElement`: Abstract base level parser element class.
    - `parserFwk.pyparsing.ParseElementEnhance`: Abstract subclass of ParserElement, for combining and post-processing parsed tokens.
      - `parserFwk.pyparsing.FollowedBy`: Lookahead matching of the given parse expression.
      - `parserFwk.pyparsing.Forward`: Forward declaration of an expression to be defined later - used for recursive grammars, such as algebraic infix notation.
      - `parserFwk.pyparsing.NotAny`: Lookahead to disallow matching with the given parse expression.
      - `parserFwk.pyparsing.OneOrMore`: Repetition of one or more of the given expression.
      - `parserFwk.pyparsing.Optional`: Optional matching of the given expression.
      - `parserFwk.pyparsing.SkipTo`: Token for skipping over all undefined text until the matched expression is found.
      - `parserFwk.pyparsing.TokenConverter`: Abstract subclass of ParseExpression, for converting parsed results.
        - `parserFwk.pyparsing.Combine`: Converter to concatenate all matching tokens to a single string.
        - `parserFwk.pyparsing.Dict`: Converter to return a repetitive expression as a list, but also as a dictionary.
        - `parserFwk.pyparsing.Group`: Converter to return the matched tokens as a list - useful for returning tokens of ZeroOrMore and OneOrMore expressions.
        - `parserFwk.pyparsing.Suppress`: Converter for ignoring the results of a parsed expression.
        - `parserFwk.pyparsing.Upcase`: Converter to upper case all matching tokens.
      - `parserFwk.pyparsing.ZeroOrMore`: Optional repetition of zero or more of the given expression.
    - `parserFwk.pyparsing.ParseExpression`: Abstract subclass of ParserElement, for combining and post-processing parsed tokens.
      - `parserFwk.pyparsing.And`: Requires all given ParseExpressions to be found in the given order.
      - `parserFwk.pyparsing.Each`: Requires all given ParseExpressions to be found, but in any order.
      - `parserFwk.pyparsing.MatchFirst`: Requires that at least one ParseExpression is found.
      - `parserFwk.pyparsing.Or`: Requires that at least one ParseExpression is found.
    - `parserFwk.pyparsing.Token`: Abstract ParserElement subclass, for defining atomic matching patterns.
      - `parserFwk.pyparsing.CharsNotIn`: Token for matching words composed of characters *not* in a given set.
      - `parserFwk.pyparsing.Empty`: An empty token, will always match.
      - `parserFwk.pyparsing.Keyword`: Token to exactly match a specified string as a keyword, that is, it must be immediately followed by a non-keyword character.
        - `parserFwk.pyparsing.CaselessKeyword`
      - `parserFwk.pyparsing.Literal`: Token to exactly match a specified string.
        - `parserFwk.pyparsing.CaselessLiteral`: Token to match a specified string, ignoring case of letters.
      - `parserFwk.pyparsing.NoMatch`: A token that will never match.
      - `parserFwk.pyparsing.QuotedString`: Token for matching strings that are delimited by quoting characters.
      - `parserFwk.pyparsing.Regex`: Token for matching strings that match a given regular expression.
      - `parserFwk.pyparsing.White`: Special matching class for matching whitespace.
      - `parserFwk.pyparsing.Word`: Token for matching words composed of allowed character sets.
  - `parserFwk.pyparsing.ParseResults`: Structured parse results, to provide multiple means of access to the parsed data:
  - `__builtin__.type`: type(object) -> the object's type type(name, bases, dict) -> a new type
- `exceptions.Exception`: Common base class for all exceptions.
  - `parserFwk.pyparsing.ParseBaseException`: base exception class for all parsing runtime exceptions
    - `parserFwk.pyparsing.ParseException`: exception thrown when parse expressions don't match class; supported attributes by name are:
    - `parserFwk.pyparsing.ParseFatalException`: user-throwable exception thrown when inconsistent parse content is found; stops all parsing immediately
  - `parserFwk.pyparsing.RecursiveGrammarException`: exception thrown by validate() if the grammar could be improperly recursive

Generated by Epydoc 2.1 on Wed Apr 11 17:02:38 2007 | http://epydoc.sf.net